README
=======

./kamaki is a simple, yet intuitive, command-line tool/interactive shell for managing clouds.

It is an initial implementation of the OpenStack Compute API, v1.1, with custom
extensions specific to the Synnefo IaaS cloud management software.
